/****************************************************************************
 * Copyright (c) 2010-2012, EBM WebSourcing - All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ****************************************************************************/
 
package com.ebmwebsourcing.easycommons.lang;

import static org.junit.Assert.assertArrayEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

/**
 * @author Adrien Ruffie - EBM WebSourcing
 */
public class ArrayHelperTest {

    @Test
    public void testMergeArrays0() throws Exception {
        Integer[] mergedArray = ArrayHelper.mergeArrays(new Integer[0]);
        assertArrayEquals(new Integer[0], mergedArray);
    }

    @Test
    public void testMergeArrays1() throws Exception {
        Integer[] mergedArray = ArrayHelper.mergeArrays(new Integer[0],
                new Integer[0], new Integer[0]);
        assertArrayEquals(new Integer[0], mergedArray);
    }

    @Test
    public void testMergeArrays2() throws Exception {
        Integer[] mergedArray = ArrayHelper.mergeArrays(
                new Integer[] { 1, 2, 3 }, new Integer[] { 4, 5 },
                new Integer[] { 6 });
        assertArrayEquals(new Integer[] { 1, 2, 3, 4, 5, 6 }, mergedArray);
    }

    @Test
    public void testArrayRemove0() throws Exception {
        Integer[] originalArray = new Integer[] { 1, 2, 3, 4, 5, 6 };
        Integer[] result = ArrayHelper.arrayRemove(originalArray);
        assertArrayEquals(originalArray, result);
    }

    @Test
    public void testArrayRemove1() throws Exception {
        Integer[] originalArray = new Integer[] { 1, 2, 3, 4, 5, 6 };
        Integer[] result = ArrayHelper.arrayRemove(originalArray, 7, 8, 9);
        assertArrayEquals(originalArray, result);
    }

    @Test
    public void testArrayRemove2() throws Exception {
        Integer[] originalArray = new Integer[] { 1, 2, 3, 4, 5, 6 };
        Integer[] result = ArrayHelper.arrayRemove(originalArray, 2, 3, 5);
        assertArrayEquals(new Integer[] { 1, 4, 6 }, result);
    }

    @Test
    public void testArrayContainsSameObject0() throws Exception {
        StringBuilder s1 = new StringBuilder("s1");
        StringBuilder s2 = new StringBuilder("s2");
        StringBuilder s3 = new StringBuilder("s3");
        StringBuilder[] array = new StringBuilder[] { s1, s2, s3 };
        for (StringBuilder s : new StringBuilder[] { s1, s2, s3 }) {
            assertTrue(ArrayHelper.arrayContainsSameObject(array, s));
        }
    }

    @Test
    public void testArrayContainsSameObject1() throws Exception {
        StringBuilder s1 = new StringBuilder("s1");
        StringBuilder s2 = new StringBuilder("s2");
        StringBuilder s3 = new StringBuilder("s3");
        StringBuilder[] array = new StringBuilder[] { s1, s2, s3 };
        for (StringBuilder s : new StringBuilder[] { new StringBuilder("s1"), new StringBuilder("s2"),
                new StringBuilder("s3") }) {
            assertFalse(ArrayHelper.arrayContainsSameObject(array, s));
        }
    }

}
