/****************************************************************************
 * Copyright (c) 2010-2012, EBM WebSourcing - All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ****************************************************************************/

package com.ebmwebsourcing.easycommons.lang;

import java.util.ArrayList;
import java.util.List;

import org.junit.Test;

import static org.junit.Assert.assertEquals;

import com.ebmwebsourcing.easycommons.lang.CollectionHelper.Filter;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 * 
 */
public class CollectionHelperTest {

    class PairNumberFilter implements Filter<Integer> {

        @Override
        public boolean accept(Integer item) {
            return item % 2 == 0;
        }

    }

    class NumberFourFilter implements Filter<Integer> {

        @Override
        public boolean accept(Integer item) {
            return item == 4;
        }

    }

    @Test
    public void filterListWithOneFilter() {
        List<Integer> lst = new ArrayList<Integer>();
        for (int i = 1; i <= 10; i++) {
            lst.add(i);
        }
        assertEquals(10, lst.size());
        List<Filter<Integer>> filters = new ArrayList<CollectionHelper.Filter<Integer>>();
        filters.add(new PairNumberFilter());
        CollectionHelper.filter(lst, filters);
        assertEquals(5, lst.size());
        int i = 2;
        for (Integer integer : lst) {
            assertEquals(i, integer.intValue());
            i += 2;
        }
    }

    @Test
    public void filterListWithTwoFilter() {
        List<Integer> lst = new ArrayList<Integer>();
        for (int i = 1; i <= 10; i++) {
            lst.add(i);
        }
        assertEquals(10, lst.size());
        List<Filter<Integer>> filters = new ArrayList<CollectionHelper.Filter<Integer>>();
        filters.add(new PairNumberFilter());
        filters.add(new NumberFourFilter());
        CollectionHelper.filter(lst, filters);
        assertEquals(1, lst.size());
        assertEquals(4, lst.get(0).intValue());
    }
}
