/****************************************************************************
 * Copyright (c) 2010-2012, EBM WebSourcing - All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ****************************************************************************/
 
package com.ebmwebsourcing.easycommons.lang;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.assertFalse;
import org.junit.Test;

/**
 * @author Mathieu CARROLLE - EBM WebSourcing
 */
public class StringHelperTest {

    @Test
    public void testIsNullOrEmptyWithNullObject() {
        assertTrue(StringHelper.isNullOrEmpty(null));
    }

    @Test
    public void testIsNullOrEmptyWithEmptyString() {
        assertTrue(StringHelper.isNullOrEmpty(new String("")));
    }

    @Test
    public void testIsNullOrEmptyWithNonEmptyString() {
        assertFalse(StringHelper.isNullOrEmpty(new String("John doe")));
    }

    @Test
    public void testNonNullValueWithNullObject() {
        Object obj = null;
        String result = StringHelper.nonNullValue(obj);
        assertNotNull(result);
        assertTrue(result.length() == 0);
    }

    @Test
    public void testNonNullValueWithNonNullObject() {
        Integer integer = new Integer(4);
        String result = StringHelper.nonNullValue(integer);
        assertNotNull(result);
        assertTrue(result.equals("4"));
    }

    @Test
    public void testEqualsWithNullInstance() {
        String s1 = null;
        String s2 = null;
        assertTrue(StringHelper.equal(s1, s2));
    }

    @Test
    public void testEqualsWithOneNullInstance() {
        String s1 = null;
        String s2 = "test";
        assertFalse(StringHelper.equal(s1, s2));
        assertFalse(StringHelper.equal(s2, s1));
    }

    @Test
    public void testEqualsWithNonNullInstance() {
        String s1 = "petals";
        String s2 = "petals";
        assertTrue(StringHelper.equal(s1, s2));
    }
}
